@@ -252,6 +252,24 @@ $(function() {
     }
   });
 
+  registerEvent('timestamp', function(msg) { // timestamp
+    //Loop through every item and update the running duration
+    $('.item').each(function(i, obj) {
+       //Calculate the difference between the current server time and the item start time
+       timeDiff = parseInt(msg.timestamp) - parseInt($(obj).attr('attr-start_time'));
+       
+       // Generate friendly time display
+       // http://stackoverflow.com/questions/1322732/convert-seconds-to-hh-mm-ss-with-javascript
+       var hours = parseInt( timeDiff / 3600 ) % 24;
+       var minutes = parseInt( timeDiff / 60 ) % 60;
+       var seconds = timeDiff % 60;
+       var result = (hours < 10 ? "0" + hours : hours) + "h " + (minutes < 10 ? "0" + minutes : minutes) + "m " + (seconds  < 10 ? "0" + seconds : seconds) + "s ";
+       
+       //Save the calculated duration back to the DOM
+       $(".item-duration-counter", obj).text('Elapsed: ' + result);
+    });
+  });
+
   function reloadProjectsTab() {
     $('#projects').load('/api/all-projects', null, function() {
       $("#projects input[type='submit']").each(makeButtonLink);
@@ -416,8 +434,7 @@ $(function() {
     $(h3).append($("<span>", { "class": 'twisty' }),
                  $("<span>", {
                      "class": 'name',
-                     text: item.name,
-                     title: item.project,
+                     text: item.name
                  }),
                  $("<span>", { "class": 'status-line' }),
                  $("<span>", { "class": 'log-line' }));
@@ -458,12 +475,24 @@ $(function() {
       }
     }
     itemDiv.appendChild(ol);
-
+    
+    var att_starttime = document.createAttribute("attr-start_time");
+    att_starttime.value = item.start_time;
+    itemDiv.setAttributeNode(att_starttime);
+    
     pre = document.createElement('pre');
     pre.className = 'log';
     pre.data = processCarriageReturns(item.output);
     pre.appendChild(document.createTextNode(pre.data));
     itemDiv.appendChild(pre);
+    
+    var logHeaderElement = $("<div>", { "class": "log-header" });
+    var durationCounterElement = $("<span>", { "class": 'item-duration-counter' });
+    
+    $(logHeaderElement)
+      .append($("<span>", { "class": "item-project-name", "text": item.project }))
+      .append(durationCounterElement);
+    $(itemDiv).append(logHeaderElement);
 
     if (!skipAnimation) {
       itemDiv.style.display = 'none';
